@@ -51,9 +51,10 @@
 
 extern F_arrow		*forward_arrow(), *backward_arrow();
 extern int		figure_modified;
-extern int		errno;
+#ifndef __NetBSD__
 extern char		*sys_errlist[];
 extern int		sys_nerr, errno;
+#endif
 
 static F_ellipse	*read_ellipseobject();
 static F_line		*read_lineobject();
@@ -410,9 +411,9 @@ FILE	*fp;
 	    return(NULL);
 	    }
 	if (t == DRAW_CLOSEDSPLINE)
-	    s->type = T_CLOSED_NORMAL;
+	    s->type = T_CLOSED_APPROX;
 	else
-	    s->type = T_OPEN_NORMAL;
+	    s->type = T_OPEN_APPROX;
 	if (f) {
 	    s->for_arrow = forward_arrow();
 	    s->for_arrow->wid = w;
@@ -456,7 +457,7 @@ FILE	*fp;
 	t->pen = 0;
 	t->angle = 0.0;
 	t->next = NULL;
-	n = fscanf(fp," %d %d %d %d %d %d %d %[^\n]", &t->font, 
+	n = fscanf(fp," %d %lf %d %lf %lf %d %d %[^\n]", &t->font, 
 		&t->size, &t->flags, &t->height, &t->length, 
 		&t->base_x, &t->base_y, buf);
 	if (n != 8) {
